| calcA | R Documentation |
Part of Genetic Value Analysis
calcA(alleles, threshold = 1L, byID = FALSE)
alleles |
a matrix with {V1 ... Vn, id, parent} providing the alleles an animal received during each simulation. The first n columns provide the alleles; the final two columns provide the animal ID and the parent the allele came from. |
threshold |
an integer indicating the maximum number of copies of an allele that can be present in the population for it to be considered rare. Default is 1. |
byID |
logical variable of length 1 that is passed through to
eventually be used by |
A matrix with named rows indicating the number of unique alleles an animal had during each round of simulation (indicated in columns).
Ballou JD, Lacy RC. 1995. Identifying genetically important individuals for management of genetic variation in pedigreed populations, p 77-111. In: Ballou JD, Gilpin M, Foose TJ, editors. Population management for survival and recovery. New York (NY): Columbia University Press.
MacCluer JW, et al. 1986. Pedigree analysis by computer simulation. Zoo Biology 5:147-160.
Other genetic value analysis:
calcFE(),
calcFEFG(),
calcFG(),
calcFGSE(),
calcGU(),
calcGUSE(),
calcGeneDiversity(),
calcNeSexRatio(),
calcNeVariance(),
calcRetention()
library(nprcgenekeepr)
rare <- calcA(nprcgenekeepr::ped1Alleles, threshold = 3, byID = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.