checkErrorLst: Check an error list for non-empty fields

View source: R/checkErrorLst.R

checkErrorLstR Documentation

Check an error list for non-empty fields

Description

Check an error list for non-empty fields

Usage

checkErrorLst(errorLst)

Arguments

errorLst

list with fields for each type of error detectable by qcStudbook.

Value

Returns FALSE if all fields are empty or the list is NULL otherwise TRUE.

Examples

errorLst <- qcStudbook(nprcgenekeepr::pedFemaleSireMaleDam,
  reportErrors = TRUE
)
checkErrorLst(errorLst)

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.