convertFromCenter: Convert from-center information to a logical value

View source: R/convertFromCenter.R

convertFromCenterR Documentation

Convert from-center information to a logical value

Description

Part of Pedigree Curation

Usage

convertFromCenter(fromCenter)

Arguments

fromCenter

character or logical vector or NA indicating whether or not the animal is from the center.

Value

A logical vector specifying TRUE if an animal is from the center otherwise FALSE.

Examples

original <- c(
  "y", "yes", "Y", "Yes", "YES", "n", "N", "No", "NO", "no",
  "t", "T", "True", "true", "TRUE", "f", "F", "false", "False",
  "FALSE"
)
convertFromCenter(original)

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.