createExampleFiles: Create example pedigree and ID-list CSV files

View source: R/createExampleFiles.R

createExampleFilesR Documentation

Create example pedigree and ID-list CSV files

Description

Creates a folder named ExamplePedigrees under the R session temporary directory (as returned by tempdir()) if it does not already exist. It then proceeds to write each example pedigree into a CSV file named based on the name of the example pedigree.

Usage

createExampleFiles()

Value

A vector of the names of the files written.

Examples

library(nprcgenekeepr)
files <- createExampleFiles()

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.