exampleNprcgenekeeprConfig: Example nprcgenekeepr configuration file (loadable)

exampleNprcgenekeeprConfigR Documentation

Example nprcgenekeepr configuration file (loadable)

Description

A loadable version of the example configuration file example_nprcgenekeepr_config. It contains a working version of a nprcgenekeepr configuration file created at the SNPRC. Users of LabKey's EHR can adapt it to their systems and put it in their home directory. Instructions are embedded as comments within the file.

Usage

data(exampleNprcgenekeeprConfig)

Format

An object of class character of length 34.

Examples

library(nprcgenekeepr)
data("exampleNprcgenekeeprConfig")
head(exampleNprcgenekeeprConfig)

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.