| examplePedigree | R Documentation |
A pedigree object created by qcStudbook.
Represents pedigree from ExamplePedigree.csv.
– character column of animal IDs
– the male parent of the animal indicated by the id
column. Unknown sires are indicated with NA
– the female parent of the animal indicated by the id
column. Unknown dams are indicated with NA
– factor with levels: "F", "M", "H", "U". Sex specifier for an individual.
– generation number (integers beginning with 0 for the founder
generation) of the animal indicated by the id column.
– Date vector of birth dates
– Date vector of exit dates
– numerical vector of age in years
– factor with levels: INDIAN, CHINESE, HYBRID, JAPANESE, OTHER, UNKNOWN indicating the geographic population of origin.
– character vector or NA (optional) that indicates
the name of the facility that the individual was imported from if other than
local.
– character vector or NA. Flag indicating an individual's status as alive, dead, sold, etc. Transformed to factor {levels: ALIVE, DECEASED, SHIPPED, UNKNOWN}. Vector of standardized status codes with the possible values ALIVE, DECEASED, SHIPPED, or UNKNOWN
– character vector with value of "added" or
"original".
– logical vector indicating whether the animal was
born at the local center (colony-origin), derived from origin and
recordStatus: TRUE when origin is blank and
recordStatus is "original"; FALSE for animals
imported from elsewhere (non-blank origin) or for synthetic
placeholder second-parent rows (recordStatus == "added") whose
true origin is not confirmed. Required by
getPotentialParents to identify in-colony candidate
parents.
data(examplePedigree)
An object of class data.frame with 3694 rows and 13 columns.
library(nprcgenekeepr)
data("examplePedigree")
exampleTree <- createPedTree(examplePedigree)
exampleLoops <- findLoops(exampleTree)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.