finalRpt: Genetic-value report list prior to ranking

finalRptR Documentation

Genetic-value report list prior to ranking

Description

A list object created from the list object rpt prepared by reportGV. It is created inside orderReport. This version is at the state just prior to calling rankSubjects inside orderReport.

Usage

data(finalRpt)

Format

An object of class list of length 3.

Examples

library(nprcgenekeepr)
data("finalRpt")
finalRpt <- rankSubjects(finalRpt)

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.