fixColumnNames: Standardize pedigree column names

View source: R/fixColumnNames.R

fixColumnNamesR Documentation

Standardize pedigree column names

Description

Standardize pedigree column names

Usage

fixColumnNames(orgCols, errorLst)

Arguments

orgCols

character vector with ordered list of column names found in a pedigree file.

errorLst

list object with places to store the various column name changes.

Value

A list object with newColNames and errorLst with a record of all changes made.

Examples

library(nprcgenekeepr)
fixColumnNames(c("Sire_ID", "EGO", "DAM", "Id", "birth_date"),
  errorLst = getEmptyErrorLst()
)

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.