getBoxWhiskerDescription: Get Box and Whisker Plot Description

View source: R/getBoxWhiskerDescription.R

getBoxWhiskerDescriptionR Documentation

Get Box and Whisker Plot Description

Description

Returns a description of how box and whisker plots work, suitable for use in popovers and tooltips in the Shiny application.

Usage

getBoxWhiskerDescription()

Value

Character string containing the box and whisker plot description explaining whiskers, IQR (inter-quartile range), and outliers.

See Also

modSummaryStatsServer which uses this for popovers

Examples

desc <- getBoxWhiskerDescription()
cat(desc)


nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.