getCurrentAge: Calculate current age in years from a birth date

View source: R/getCurrentAge.R

getCurrentAgeR Documentation

Calculate current age in years from a birth date

Description

Assumes current date for calculating age.

Usage

getCurrentAge(birth)

Arguments

birth

birth date(s)

Value

Age in years using the provided birthdate.

Examples

library(nprcgenekeepr)
age <- getCurrentAge(birth = as.Date("06/02/2000", format = "%m/%d/%Y"))

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.