Skip to contents

Get genotypes from file

Usage

getGenotypes(fileName, sep = ",")

Arguments

fileName

character vector of length one: the path of a delimited text file or an Excel (xls/xlsx) file.

sep

column separator in a delimited text file; ignored for an Excel file.

Value

The file's contents as an unchecked dataframe (column names are not changed). In a delimited text file an empty string and "NA" are read as NA. Pass the result to checkGenotypeFile to make it compatible with the other functions in this package.

Examples

library(nprcgenekeepr)
pedCsv <- getGenotypes(fileName = system.file("testdata", "qcPed.csv",
  package = "nprcgenekeepr"
))