getIncludeColumns: Get the superset of columns that can be in a pedigree file

View source: R/getIncludeColumns.R

getIncludeColumnsR Documentation

Get the superset of columns that can be in a pedigree file

Description

Part of Genetic Value Functions

Usage

getIncludeColumns()

Details

Replaces INCLUDE.COLUMNS data statement.

Value

Superset of columns that can be in a pedigree file.

Examples

getIncludeColumns()

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.