getLkDirectAncestors: Get the direct ancestors of selected animals

View source: R/getLkDirectAncestors.R

getLkDirectAncestorsR Documentation

Get the direct ancestors of selected animals

Description

Gets direct ancestors from labkey study schema and demographics table.

Usage

getLkDirectAncestors(ids)

Arguments

ids

character vector of animal IDs

Value

data.frame with pedigree structure having all of the direct ancestors for the Ids provided.

See Also

Other direct relatives: getFileDirectRelatives(), getLkDirectRelatives(), getPedDirectRelatives()

Examples

## Not run: 
# Requires LabKey connection
library(nprcgenekeepr)
## Have to a vector of focal animals
focalAnimals <- c("1X2701", "1X0101")
suppressWarnings(getLkDirectAncestors(ids = focalAnimals))

## End(Not run)

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.