View source: R/getPedDirectRelatives.R
| getPedDirectRelatives | R Documentation |
Gets the direct relatives (ancestors and descendants) of the selected
animals from the supplied pedigree (ped).
getPedDirectRelatives(ids, ped, unrelatedParents = FALSE)
ids |
character vector of animal IDs |
ped |
pedigree dataframe object that is used as the source of pedigree information. |
unrelatedParents |
logical vector when |
A data.frame of pedigree records for the selected animals and
their direct relatives (ancestors and descendants) in ped.
Other direct relatives:
getFileDirectRelatives(),
getLkDirectAncestors(),
getLkDirectRelatives()
library(nprcgenekeepr)
## A pedigree to search and a focal animal whose direct relatives we want
ped <- nprcgenekeepr::lacy1989Ped
getPedDirectRelatives(ids = "E", ped = ped)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.