| getPedMaxAge | R Documentation |
Returns the maximum age among all animals in the pedigree that have a non-NA age. Because ages are computed for deceased animals (age at exit) as well, the maximum can reflect a deceased animal.
getPedMaxAge(ped)
ped |
The pedigree information in data.frame format |
Numeric value representing the maximum age of animals in the
pedigree, or NA_real_ if no animal has a non-missing age (no
age column or all ages missing).
library(nprcgenekeepr)
examplePedigree <- nprcgenekeepr::examplePedigree
ped <- qcStudbook(examplePedigree,
minParentAge = 2,
reportChanges = FALSE,
reportErrors = FALSE
)
getPedMaxAge(ped)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.