View source: R/getPotentialSires.R
| getPotentialSires | R Documentation |
List potential sires
getPotentialSires(ids, ped, minAge = 1L)
ids |
character vector of animal IDs |
ped |
dataframe that is the |
minAge |
integer value giving the inclusive minimum current age (in years) a male must have to be listed as a potential sire. Default is 1 year. |
A character vector of potential sire Ids
library(nprcgenekeepr)
ped <- nprcgenekeepr::pedWithGenotype
ids <- nprcgenekeepr::qcBreeders
getPotentialSires(ids, ped, minAge = 1L)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.