View source: R/getPyramidPlot.R
| getPyramidPlot | R Documentation |
The pedigree provided must have the following columns: sex and
age. This needs to be augmented to allow pedigrees structures that
are provided by the nprcgenekeepr package.
getPyramidPlot(
ped = NULL,
binWidth = 2L,
ageUnit = "years",
colorScheme = "default",
showCounts = TRUE,
ageLabelCex = 1
)
ped |
The pedigree information in data.frame format |
binWidth |
numeric bin width for age groups (default 2). |
ageUnit |
character either "years" (default) or "months". |
colorScheme |
character color scheme: "default" (blue/pink) or "viridis" (colorblind-friendly). |
showCounts |
logical whether to show count values on bars (default TRUE). |
ageLabelCex |
numeric expansion factor for age labels (default 1.0). |
The return value of par("mar") when the function was called.
library(nprcgenekeepr)
data(qcPed)
getPyramidPlot(qcPed)
getPyramidPlot(qcPed, binWidth = 5, colorScheme = "viridis")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.