getSiteInfo: Get site information

View source: R/getSiteInfo.R

getSiteInfoR Documentation

Get site information

Description

Get site information

Usage

getSiteInfo(expectConfigFile = TRUE)

Arguments

expectConfigFile

logical parameter when set to FALSE, no configuration is looked for. Default value is TRUE.

Value

A list of site specific information used by the application.

Currently this returns the following character strings in a named list.

  1. center – One of "SNPRC" or "ONPRC"

  2. baseUrl – If center is "SNPRC", baseUrl is one of "https://boomer.txbiomed.local:8080/labkey" or "https://vger.txbiomed.local:8080/labkey". To allow testing, if center is "ONPRC" baseUrl is "https://boomer.txbiomed.local:8080/labkey".

  3. schemaName – If center is "SNPRC", schemaName is "study". If center is "ONPRC", schemaName is "study"

  4. folderPath – If center is "SNPRC", folderPath is "/SNPRC". If center is "ONPRC", folderPath is "/ONPRC"

  5. queryName – is "demographics"

  6. requiredCols – the required studbook columns, from getRequiredCols

  7. possibleCols – the possible studbook columns, from getPossibleCols

  8. includeColumns – the superset of report-inclusion columns, from getIncludeColumns

Examples

library(nprcgenekeepr)
## default sends warning if configuration file is missing
suppressWarnings(getSiteInfo())
getSiteInfo(expectConfigFile = FALSE)

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.