headerDisplayNames: Convert internal column names to display or header names

View source: R/headerDisplayNames.R

headerDisplayNamesR Documentation

Convert internal column names to display or header names

Description

Converts the column names of a Pedigree or Genetic value Report to something more descriptive.

Usage

headerDisplayNames(headers)

Arguments

headers

a character vector of column (header) names

Value

Updated list of column names

Examples

library(nprcgenekeepr)
headerDisplayNames(headers = c("id", "sire", "dam", "sex", "birth", "age"))

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.