| makeCEPH | R Documentation |
Part of Relations
makeCEPH(id, sire, dam)
id |
character vector with unique identifier for an individual |
sire |
character vector with unique identifier for an
individual's father ( |
dam |
character vector with unique identifier for an
individual's mother ( |
Creates a CEPH-style pedigree for each id, consisting of three generations: the id, the parents, and the grandparents. Inserts NA for unknown pedigree members.
List of lists: fields: id, subfields: parents, pgp, mgp. Pedigree information converted into a CEPH-style list. The top level list elements are the IDs from id. Below each ID is a list of three elements: parents (sire, dam), paternal grandparents (pgp: sire, dam), and maternal grandparents (mgp: sire, dam).
library(nprcgenekeepr)
ped <- nprcgenekeepr::lacy1989Ped
pedCEPH <- makeCEPH(ped$id, ped$sire, ped$dam)
head(ped)
head(pedCEPH$F)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.