Skip to contents

Uses examplePedigree data structure to create an example data file. Files of type "csv" and "txt" are silently overwritten if they already exist. A file of type "excel" is never overwritten; if the file already exists, an error is signaled.

Usage

makeExamplePedigreeFile(
  file = file.path(tempdir(), "examplePedigree.csv"),
  fileType = "csv"
)

Arguments

file

character vector of length one providing the file name

fileType

character vector of length one with possible values of "txt", "csv", or "excel". Default value is "csv".

Value

Full path name of file saved.

Examples

library(nprcgenekeepr)
pedigreeFile <- makeExamplePedigreeFile()