View source: R/makeFounderStatsTable.R
| makeFounderStatsTable | R Documentation |
Generates an HTML table displaying founder statistics including counts of known founders, male founders, female founders, founder equivalents (FE), and founder genome equivalents (FG).
makeFounderStatsTable(founderStats)
founderStats |
list containing founder statistics with elements:
|
Character string containing HTML table markup.
makeGeneticSummaryTable for genetic value summary
calcFE for founder equivalents calculation
calcFG for founder genome equivalents
stats <- list(
total = 50,
nMaleFounders = 20,
nFemaleFounders = 30,
fe = 25.5,
fg = 22.3
)
html <- makeFounderStatsTable(stats)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.