makeGrpNum: Deprecated alias for makeGroupNum

View source: R/makeGroupNum.R

makeGrpNumR Documentation

Deprecated alias for makeGroupNum

Description

makeGrpNum has been renamed to makeGroupNum for consistency with makeGroupMembers. It remains as a deprecated wrapper that issues a warning and then calls makeGroupNum.

Usage

makeGrpNum(numGp)

Arguments

numGp

integer value indicating the number of groups that should be formed from the list of IDs. Default is 1.

Value

Initial grpNum list

See Also

makeGroupNum


nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.