View source: R/modBreedingGroups.R
| modBreedingGroupsUI | R Documentation |
Breeding Groups Module - UI Function
modBreedingGroupsUI(id)
id |
character vector of length 1. Module namespace identifier. |
A div containing breeding group formation UI.
Vinson, A. and Raboin, M.J. (2015) "A Practical Approach for Designing Breeding Groups to Maximize Genetic Diversity in a Large Colony of Captive Rhesus Macaques (Macaca mulatta)" Journal of the American Association for Laboratory Animal Science, 2015 Nov, Vol.54(6), pp.700-707.
modBreedingGroupsServer
groupAddAssign for group formation algorithm.
Other Shiny modules:
modBreedingGroupsServer(),
modGeneticDiversityServer(),
modGeneticDiversityUI(),
modGeneticValueServer(),
modGeneticValueUI(),
modGvAndBgDescServer(),
modGvAndBgDescUI(),
modInputServer(),
modInputUI(),
modORIPReportingServer(),
modORIPReportingUI(),
modPedigreeServer(),
modPedigreeUI(),
modPotentialParentsServer(),
modPotentialParentsUI(),
modPyramidServer(),
modPyramidUI(),
modSummaryStatsServer(),
modSummaryStatsUI()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.