modGvAndBgDescServer: Genetic Value and Breeding Group Description Module - Server...

View source: R/modGvAndBgDesc.R

modGvAndBgDescServerR Documentation

Genetic Value and Breeding Group Description Module - Server Function

Description

Server logic for genetic value and breeding group description module. This module is primarily informational and does not require reactive logic.

Usage

modGvAndBgDescServer(id)

Arguments

id

character vector of length 1. Module namespace identifier.

Value

NULL (no reactive outputs).

See Also

modGvAndBgDescUI for the user interface.

Other Shiny modules: modBreedingGroupsServer(), modBreedingGroupsUI(), modGeneticDiversityServer(), modGeneticDiversityUI(), modGeneticValueServer(), modGeneticValueUI(), modGvAndBgDescUI(), modInputServer(), modInputUI(), modORIPReportingServer(), modORIPReportingUI(), modPedigreeServer(), modPedigreeUI(), modPotentialParentsServer(), modPotentialParentsUI(), modPyramidServer(), modPyramidUI(), modSummaryStatsServer(), modSummaryStatsUI()


nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.