pedFemaleSireMaleDam: Example studbook with sex-mismatched parents

pedFemaleSireMaleDamR Documentation

Example studbook with sex-mismatched parents

Description

A data frame with 8 rows and 5 columns (ego_id, sire.id, dam_id, sex, birth_date) representing a full pedigree with the errors of having a sire labeled as female and a dam labeled as male.

Usage

data(pedFemaleSireMaleDam)

Format

An object of class data.frame with 8 rows and 5 columns.

Details

It is one of six pedigrees (pedDuplicateIds, pedFemaleSireMaleDam, pedGood, pedInvalidDates, pedMissingBirth, pedSameMaleIsSireAndDam) used to demonstrate error detection by the qcStudbook function.


nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.