pedSameMaleIsSireAndDam: Example studbook with a male as both sire and dam

pedSameMaleIsSireAndDamR Documentation

Example studbook with a male as both sire and dam

Description

A data frame with 8 rows and 5 columns (ego_id, sire.id, dam_id, sex, birth_date) representing a full pedigree in which the same male animal is listed as both a sire and a dam.

Usage

data(pedSameMaleIsSireAndDam)

Format

An object of class data.frame with 8 rows and 5 columns.

Details

It is one of six pedigrees (pedDuplicateIds, pedFemaleSireMaleDam, pedGood, pedInvalidDates, pedMissingBirth, pedSameMaleIsSireAndDam) used to demonstrate error detection by the qcStudbook function.


nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.