powered by
qcPedGvReport is a genetic value report for illustrative purposes only. It is used in examples and unit tests with the nprcgenekeepr package. It was created using the following commands.
set_seed(10)
qcPedGvReport <- reportGV(nprcgenekeepr::qcPed, guIter = 10000)
save(qcPedGvReport, file = "data/qcPedGvReport.RData")
data(qcPedGvReport)
An object of class list (inherits from nprcgenekeeprGV) of length 11.
list
nprcgenekeeprGV
qcPedGvReport <- nprcgenekeepr::qcPedGvReport
Run the code above in your browser using DataLab