| rhesusPedigree | R Documentation |
A pedigree object. Represents an obfuscated pedigree from obfuscated_rhesus_mhc_ped.csv where the IDs and dates have been modified to de-identify the data.
– character column of animal IDs
– the male parent of the animal indicated by the id
column. Unknown sires are indicated with NA
– the female parent of the animal indicated by the id
column. Unknown dams are indicated with NA
– factor with levels: "F", "M". Sex specifier for an individual.
– generation number (integers beginning with 0 for the founder
generation) of the animal indicated by the id column.
– Date vector of birth dates
– Date vector, all NA (no exit dates are recorded
in this obfuscated pedigree)
– numerical vector of age in years
data(rhesusPedigree)
An object of class data.frame with 375 rows and 8 columns.
library(nprcgenekeepr)
data("rhesusPedigree")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.