View source: R/saveDataframesAsFiles.R
| saveDataframesAsFiles | R Documentation |
Takes a list of dataframes and creates a file based on the list name of the dataframe and the extension for the file type.
saveDataframesAsFiles(dfList, baseDir, fileType = "csv")
dfList |
list of dataframes to be stored as files. |
baseDir |
character vector of length on with the directory path. |
fileType |
character vector of length one with possible values of
|
Full path name of files saved.
library(nprcgenekeepr)
dfList <- list(
lacy1989Ped = nprcgenekeepr::lacy1989Ped,
pedGood = nprcgenekeepr::pedGood
)
## Write each data frame to a CSV file under a temporary directory.
files <- saveDataframesAsFiles(dfList,
baseDir = tempdir(), fileType = "csv"
)
basename(files)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.