View source: R/shouldShowChangedColsTab.R
| shouldShowChangedColsTab | R Documentation |
Checks the changedCols list to determine if the Changed Columns tab should be inserted into the application navigation. The tab is shown when column names were modified during QC processing.
shouldShowChangedColsTab(changedCols)
changedCols |
list containing information about changed column names.
Expected fields include: |
Logical. TRUE if columns were changed and tab should be shown, FALSE otherwise.
checkChangedColsLst for the original implementation
library(nprcgenekeepr)
## No column changes recorded: the tab stays hidden.
shouldShowChangedColsTab(list())
## A recorded case change: the tab should be shown.
shouldShowChangedColsTab(list(caseChange = c(Id = "id")))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.