| addGenotype | R Documentation |
Assumes genotype has been opened by checkGenotypeFile
addGenotype(ped, genotype)
ped |
pedigree dataframe. |
genotype |
genotype dataframe. |
The two allele columns are coerced to character internally so the name-keyed allele dictionary is both built and indexed by allele label. This keeps the integer encoding consistent even when the allele columns are supplied as factors (a factor would otherwise be indexed by its integer codes).
A pedigree object with genotype data added.
library(nprcgenekeepr)
rhesusPedigree <- nprcgenekeepr::rhesusPedigree
rhesusGenotypes <- nprcgenekeepr::rhesusGenotypes
pedWithGenotypes <- addGenotype(
ped = rhesusPedigree,
genotype = rhesusGenotypes
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.