calcA: Count each individual's rare alleles per simulation
Description
Part of Genetic Value Analysis
Usage
calcA(alleles, threshold = 1L, byID = FALSE)
Value
A matrix with named rows indicating the number of unique alleles
an animal had during each round of simulation (indicated in columns).
Arguments
alleles
a matrix with {V1 ... Vn, id, parent} providing the alleles
an animal received during each simulation.
The first n columns provide the alleles; the final two columns provide the
animal ID and the parent the allele came from.
threshold
an integer indicating the maximum number of copies of an
allele that can be present in the population for it to be considered rare.
Default is 1.
byID
logical variable of length 1 that is passed through to
eventually be used by alleleFreq(), which calculates the count of each
allele in the provided vector. If byID is TRUE and ids are provided,
the function will only count the unique alleles for an individual
(homozygous alleles will be counted as 1).
References
Ballou JD, Lacy RC. 1995. Identifying genetically important
individuals for management of genetic variation in pedigreed populations,
p 77-111. In: Ballou JD, Gilpin M, Foose TJ, editors.
Population management for survival and recovery. New York (NY):
Columbia University Press.
MacCluer JW, et al. 1986. Pedigree analysis by computer
simulation. Zoo Biology 5:147-160.
See Also
Other genetic value analysis:
calcFE(),
calcFEFG(),
calcFG(),
calcFGSE(),
calcGU(),
calcGUSE(),
calcGeneDiversity(),
calcNeSexRatio(),
calcNeVariance(),
calcRetention()