View source: R/calcRetention.R
| calcRetention | R Documentation |
Part of Genetic Value Analysis
calcRetention(ped, alleles)
ped |
the pedigree information in datatable format. Pedigree (req. fields: id, sire, dam, gen, population). It is assumed that the pedigree has no partial parentage |
alleles |
dataframe of containing an |
A vector of the mean number of founder alleles retained in the gene dropping simulation.
Lacy RC. 1989. Analysis of founder representation in pedigrees: founder equivalents and founder genome equivalents. Zoo Biol 8:111-123.
Other genetic value analysis:
calcA(),
calcFE(),
calcFEFG(),
calcFG(),
calcFGSE(),
calcGU(),
calcGUSE(),
calcGeneDiversity(),
calcNeSexRatio(),
calcNeVariance()
library(nprcgenekeepr)
data("lacy1989Ped")
data("lacy1989PedAlleles")
ped <- lacy1989Ped
alleles <- lacy1989PedAlleles
retention <- calcRetention(ped, alleles)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.