Learn R Programming

nprcgenekeepr (version 2.0.0)

calcRetention: Calculate allelic retention

Description

Part of Genetic Value Analysis

Usage

calcRetention(ped, alleles)

Value

A vector of the mean number of founder alleles retained in the gene dropping simulation.

Arguments

ped

the pedigree information in datatable format. Pedigree (req. fields: id, sire, dam, gen, population).

It is assumed that the pedigree has no partial parentage

alleles

dataframe of containing an AlleleTable. This is a table of allele information produced by geneDrop().

References

Lacy RC. 1989. Analysis of founder representation in pedigrees: founder equivalents and founder genome equivalents. Zoo Biol 8:111-123.

See Also

Other genetic value analysis: calcA(), calcFE(), calcFEFG(), calcFG(), calcFGSE(), calcGU(), calcGUSE(), calcGeneDiversity(), calcNeSexRatio(), calcNeVariance()

Examples

Run this code
library(nprcgenekeepr)
data("lacy1989Ped")
data("lacy1989PedAlleles")
ped <- lacy1989Ped
alleles <- lacy1989PedAlleles
retention <- calcRetention(ped, alleles)

Run the code above in your browser using DataLab