Learn R Programming

nprcgenekeepr (version 2.0.0)

checkErrorLst: Check an error list for non-empty fields

Description

Check an error list for non-empty fields

Usage

checkErrorLst(errorLst)

Value

Returns FALSE if all fields are empty or the list is NULL otherwise TRUE.

Arguments

errorLst

list with fields for each type of error detectable by qcStudbook.

Examples

Run this code
errorLst <- qcStudbook(nprcgenekeepr::pedFemaleSireMaleDam,
  reportErrors = TRUE
)
checkErrorLst(errorLst)

Run the code above in your browser using DataLab