powered by
Check an error list for non-empty fields
checkErrorLst(errorLst)
Returns FALSE if all fields are empty or the list is NULL otherwise TRUE.
list with fields for each type of error detectable by qcStudbook.
qcStudbook
errorLst <- qcStudbook(nprcgenekeepr::pedFemaleSireMaleDam, reportErrors = TRUE ) checkErrorLst(errorLst)
Run the code above in your browser using DataLab