View source: R/checkParentAge.R
| checkParentAge | R Documentation |
Ensure parents are sufficiently older than offspring
checkParentAge(
sb,
minSireAge = NULL,
minDamAge = NULL,
minParentAge = lifecycle::deprecated(),
reportErrors = FALSE
)
A dataframe containing rows for each animal where one or more
parent was less than minParentAge. It contains all of the columns
in the original sb dataframe with the following added columns:
sireBirth – sire's birth date
sireAge – age of sire in years on the date indicated by
birth.
damBirth – dam's birth date
damAge – age of dam in years on the date indicated by
birth.
library(nprcgenekeepr)
qcPed <- nprcgenekeepr::qcPed
checkParentAge(qcPed, minSireAge = 2L, minDamAge = 2L)
checkParentAge(qcPed, minSireAge = 3L, minDamAge = 3L)
checkParentAge(qcPed, minSireAge = 5L, minDamAge = 5L)
checkParentAge(qcPed, minSireAge = 6L, minDamAge = 6L)
head(checkParentAge(qcPed, minSireAge = 10L, minDamAge = 10L))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.