View source: R/createExampleFiles.R
| createExampleFiles | R Documentation |
Creates a folder named ExamplePedigrees under the R session temporary
directory (as returned by tempdir()) if it does not already exist. It
then proceeds to write each example pedigree into a CSV file named based on
the name of the example pedigree.
createExampleFiles()
A vector of the names of the files written.
library(nprcgenekeepr)
files <- createExampleFiles()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.