Learn R Programming

nprcgenekeepr (version 2.0.0)

createExampleFiles: Create example pedigree and ID-list CSV files

Description

Creates a folder named ExamplePedigrees under the R session temporary directory (as returned by tempdir()) if it does not already exist. It then proceeds to write each example pedigree into a CSV file named based on the name of the example pedigree.

Usage

createExampleFiles()

Arguments

Value

A vector of the names of the files written.

Examples

Run this code
library(nprcgenekeepr)
files <- createExampleFiles()

Run the code above in your browser using DataLab