| exampleNprcgenekeeprConfig | R Documentation |
A loadable version of the example
configuration file example_nprcgenekeepr_config.
It contains a working version of a nprcgenekeepr configuration
file created at the SNPRC.
Users of LabKey's EHR can adapt it to their systems and put it
in their home directory. Instructions are embedded as comments
within the file.
data(exampleNprcgenekeeprConfig)
An object of class character of length 34.
library(nprcgenekeepr)
data("exampleNprcgenekeeprConfig")
head(exampleNprcgenekeeprConfig)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.