A pedigree object created by qcStudbook.
Represents pedigree from ExamplePedigree.csv.
- id
– character column of animal IDs
- sire
– the male parent of the animal indicated by the
idcolumn. Unknown sires are indicated withNA- dam
– the female parent of the animal indicated by the
idcolumn. Unknown dams are indicated withNA- sex
– factor with levels: "F", "M", "H", "U". Sex specifier for an individual.
- gen
– generation number (integers beginning with 0 for the founder generation) of the animal indicated by the
idcolumn.- birth
– Date vector of birth dates
- exit
– Date vector of exit dates
- age
– numerical vector of age in years
- ancestry
– factor with levels: INDIAN, CHINESE, HYBRID, JAPANESE, OTHER, UNKNOWN indicating the geographic population of origin.
- origin
– character vector or
NA(optional) that indicates the name of the facility that the individual was imported from if other than local.- status
– character vector or NA. Flag indicating an individual's status as alive, dead, sold, etc. Transformed to factor {levels: ALIVE, DECEASED, SHIPPED, UNKNOWN}. Vector of standardized status codes with the possible values ALIVE, DECEASED, SHIPPED, or UNKNOWN
- recordStatus
– character vector with value of
"added"or"original".- fromCenter
– logical vector indicating whether the animal was born at the local center (colony-origin), derived from
originandrecordStatus:TRUEwhenoriginis blank andrecordStatusis"original";FALSEfor animals imported from elsewhere (non-blankorigin) or for synthetic placeholder second-parent rows (recordStatus == "added") whose true origin is not confirmed. Required bygetPotentialParentsto identify in-colony candidate parents.
Usage
data(examplePedigree)Examples
library(nprcgenekeepr)
data("examplePedigree")
exampleTree <- createPedTree(examplePedigree)
exampleLoops <- findLoops(exampleTree)