| finalRpt | R Documentation |
A list object created from the list object rpt prepared
by reportGV. It is created inside orderReport. This version
is at the state just prior to calling rankSubjects inside
orderReport.
data(finalRpt)
An object of class list of length 3.
library(nprcgenekeepr)
data("finalRpt")
finalRpt <- rankSubjects(finalRpt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.