A list object created from the list object rpt prepared
by reportGV. It is created inside orderReport. This version
is at the state just prior to calling rankSubjects inside
orderReport.
Usage
data(finalRpt)Examples
library(nprcgenekeepr)
data("finalRpt")
finalRpt <- rankSubjects(finalRpt)