Learn R Programming

nprcgenekeepr (version 2.0.0)

finalRpt: Genetic-value report list prior to ranking

Description

A list object created from the list object rpt prepared by reportGV. It is created inside orderReport. This version is at the state just prior to calling rankSubjects inside orderReport.

Usage

data(finalRpt)

Arguments

Format

An object of class list of length 3.

Examples

Run this code
library(nprcgenekeepr)
data("finalRpt")
finalRpt <- rankSubjects(finalRpt)

Run the code above in your browser using DataLab