finalRpt: Genetic-value report list prior to ranking
Description
A list object created from the list object rpt prepared
by reportGV. It is created inside orderReport. This version
is at the state just prior to calling rankSubjects inside
orderReport.