Learn R Programming

nprcgenekeepr (version 2.0.0)

focalAnimals: Focal animal IDs from examplePedigree

Description

A dataframe with one column (id) containing the animal Ids from the examplePedigree pedigree. They can be used to illustrate the identification of a population of interest as is shown in the example below.

Usage

data(focalAnimals)

Arguments

Format

An object of class data.frame with 327 rows and 1 columns.

Examples

Run this code
library(nprcgenekeepr)
data("focalAnimals")
data("examplePedigree")
any(names(examplePedigree) == "population")
nrow(examplePedigree)
examplePedigree <- setPopulation(
  ped = examplePedigree,
  ids = focalAnimals$id
)
any(names(examplePedigree) == "population")
nrow(examplePedigree)
nrow(examplePedigree[examplePedigree$population, ])

Run the code above in your browser using DataLab