View source: R/getBoxWhiskerDescription.R
| getBoxWhiskerDescription | R Documentation |
Returns a description of how box and whisker plots work, suitable for use in popovers and tooltips in the Shiny application.
getBoxWhiskerDescription()
Character string containing the box and whisker plot description explaining whiskers, IQR (inter-quartile range), and outliers.
modSummaryStatsServer which uses this for popovers
desc <- getBoxWhiskerDescription()
cat(desc)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.