Get Box and Whisker Plot Description
Source:R/getBoxWhiskerDescription.R
getBoxWhiskerDescription.RdReturns a description of how box and whisker plots work, suitable for use in popovers and tooltips in the Shiny application.
Value
Character string containing the box and whisker plot description explaining whiskers, IQR (inter-quartile range), and outliers.
See also
modSummaryStatsServer which uses this for popovers
Examples
desc <- getBoxWhiskerDescription()
cat(desc)
#> The upper whisker extends from the hinge to the largest value no further than 1.5 * IQR from the hinge (where IQR is the inter-quartile range, or distance between the first and third quartiles). The lower whisker extends from the hinge to the smallest value at most 1.5 * IQR of the hinge. Data beyond the end of the whiskers are called "outlying" points and are plotted individually.