Learn R Programming

nprcgenekeepr (version 2.0.0)

getBoxWhiskerDescription: Get Box and Whisker Plot Description

Description

Returns a description of how box and whisker plots work, suitable for use in popovers and tooltips in the Shiny application.

Usage

getBoxWhiskerDescription()

Arguments

Value

Character string containing the box and whisker plot description explaining whiskers, IQR (inter-quartile range), and outliers.

See Also

modSummaryStatsServer which uses this for popovers

Examples

Run this code
desc <- getBoxWhiskerDescription()
cat(desc)

Run the code above in your browser using DataLab