powered by
Returns a description of how box and whisker plots work, suitable for use in popovers and tooltips in the Shiny application.
getBoxWhiskerDescription()
Character string containing the box and whisker plot description explaining whiskers, IQR (inter-quartile range), and outliers.
modSummaryStatsServer which uses this for popovers
modSummaryStatsServer
desc <- getBoxWhiskerDescription() cat(desc)
Run the code above in your browser using DataLab