getDatedFilename: Prepend the date and time to a file name

View source: R/getDatedFileName.R

getDatedFilenameR Documentation

Prepend the date and time to a file name

Description

Prepend the date and time to a file name

Usage

getDatedFilename(filename)

Arguments

filename

character vector with name to use in file name

Value

A character string with a file name prepended with the date and time in YYYY-MM-DD_hh_mm_ss_basename format.

Examples

library(nprcgenekeepr)
getDatedFilename("testName")

nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.