Prepend the date and time to a file name
Value
A character string with a file name prepended with the date and time in YYYY-MM-DD_hh_mm_ss_basename format.
Examples
library(nprcgenekeepr)
getDatedFilename("testName")
#> [1] "2026-08-04_15_45_14.345939_testName"