Skip to contents

Prepend the date and time to a file name

Usage

getDatedFilename(filename)

Arguments

filename

character vector with name to use in file name

Value

A character string with a file name prepended with the date and time in YYYY-MM-DD_hh_mm_ss_basename format.

Examples

library(nprcgenekeepr)
getDatedFilename("testName")
#> [1] "2026-07-15_14_49_15.637733_testName"