Learn R Programming

nprcgenekeepr (version 2.0.0)

getDatedFilename: Prepend the date and time to a file name

Description

Prepend the date and time to a file name

Usage

getDatedFilename(filename)

Value

A character string with a file name prepended with the date and time in YYYY-MM-DD_hh_mm_ss_basename format.

Arguments

filename

character vector with name to use in file name

Examples

Run this code
library(nprcgenekeepr)
getDatedFilename("testName")

Run the code above in your browser using DataLab