| getFounders | R Documentation |
Part of Pedigree Curation
getFounders(ped)
ped |
datatable that is the |
A founder is an animal whose sire and dam are both unknown (NA).
Animals with exactly one known parent (partial parentage) are
not founders.
A vector of the id values of the founders, in pedigree
order. It has the same type as ped$id and is empty when there are
no founders.
isFounder for the founder logical mask.
library(nprcgenekeepr)
ped <- data.frame(
id = c("A", "B", "C", "D", "E", "F", "G"),
sire = c(NA, NA, "A", "A", NA, "D", "D"),
dam = c(NA, NA, "B", "B", NA, "E", "E"),
stringsAsFactors = FALSE
)
getFounders(ped)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.