Get genotypes from file
Value
The file's contents as an unchecked dataframe (column names are
not changed). In a delimited text file an empty string and "NA" are
read as NA. Pass the result to checkGenotypeFile
to make it compatible with the other functions in this package.
Examples
library(nprcgenekeepr)
pedCsv <- getGenotypes(fileName = system.file("testdata", "qcPed.csv",
package = "nprcgenekeepr"
))