Skip to contents

Gets direct ancestors from labkey study schema and demographics table.

Usage

getLkDirectAncestors(ids)

Arguments

ids

character vector of animal IDs

Value

data.frame with pedigree structure having all of the direct ancestors for the Ids provided.

Examples

if (FALSE) { # \dontrun{
# Requires LabKey connection
library(nprcgenekeepr)
## Have to a vector of focal animals
focalAnimals <- c("1X2701", "1X0101")
suppressWarnings(getLkDirectAncestors(ids = focalAnimals))
} # }