Learn R Programming

nprcgenekeepr (version 2.0.0)

getLkDirectAncestors: Get the direct ancestors of selected animals

Description

Gets direct ancestors from labkey study schema and demographics table.

Usage

getLkDirectAncestors(ids)

Value

data.frame with pedigree structure having all of the direct ancestors for the Ids provided.

Arguments

ids

character vector of animal IDs

See Also

Other direct relatives: getFileDirectRelatives(), getLkDirectRelatives(), getPedDirectRelatives()

Examples

Run this code
if (FALSE) {
# Requires LabKey connection
library(nprcgenekeepr)
## Have to a vector of focal animals
focalAnimals <- c("1X2701", "1X0101")
suppressWarnings(getLkDirectAncestors(ids = focalAnimals))
}

Run the code above in your browser using DataLab