A data.frame of pedigree records for the selected animals and
their direct relatives (ancestors and descendants) in ped.
Arguments
ids
character vector of animal IDs
ped
pedigree dataframe object that is used as the source of
pedigree information.
unrelatedParents
logical vector when FALSE the unrelated
parents of offspring do not get a record as an ego; when TRUE they
get a place holder record as an ego in which the parent (sire,
dam) IDs are set to NA.
See Also
Other direct relatives:
getFileDirectRelatives(),
getLkDirectAncestors(),
getLkDirectRelatives()
library(nprcgenekeepr)
## A pedigree to search and a focal animal whose direct relatives we wantped <- nprcgenekeepr::lacy1989Ped
getPedDirectRelatives(ids = "E", ped = ped)