Returns the maximum age among all animals in the pedigree that have a non-NA age. Because ages are computed for deceased animals (age at exit) as well, the maximum can reflect a deceased animal.
Value
Numeric value representing the maximum age of animals in the
pedigree, or NA_real_ if no animal has a non-missing age (no
age column or all ages missing).
Examples
library(nprcgenekeepr)
examplePedigree <- nprcgenekeepr::examplePedigree
ped <- qcStudbook(examplePedigree,
minParentAge = 2,
reportChanges = FALSE,
reportErrors = FALSE
)
getPedMaxAge(ped)
#> [1] 38.4