getPedMaxAge: Get the maximum age of any animal in the pedigree
Description
Returns the maximum age among all animals in the pedigree that
have a non-NA age. Because ages are computed for deceased animals
(age at exit) as well, the maximum can reflect a deceased animal.
Usage
getPedMaxAge(ped)
Value
Numeric value representing the maximum age of animals in the
pedigree, or NA_real_ if no animal has a non-missing age (no
age column or all ages missing).