Learn R Programming

nprcgenekeepr (version 2.0.0)

getPotentialSires: List potential sires

Description

List potential sires

Usage

getPotentialSires(ids, ped, minAge = 1L)

Value

A character vector of potential sire Ids

Arguments

ids

character vector of animal IDs

ped

dataframe that is the Pedigree. It contains pedigree information including the IDs listed in ids.

minAge

integer value giving the inclusive minimum current age (in years) a male must have to be listed as a potential sire. Default is 1 year.

Examples

Run this code
library(nprcgenekeepr)
ped <- nprcgenekeepr::pedWithGenotype
ids <- nprcgenekeepr::qcBreeders
getPotentialSires(ids, ped, minAge = 1L)

Run the code above in your browser using DataLab