powered by
List potential sires
getPotentialSires(ids, ped, minAge = 1L)
A character vector of potential sire Ids
character vector of animal IDs
dataframe that is the Pedigree. It contains pedigree information including the IDs listed in ids.
Pedigree
ids
integer value giving the inclusive minimum current age (in years) a male must have to be listed as a potential sire. Default is 1 year.
library(nprcgenekeepr) ped <- nprcgenekeepr::pedWithGenotype ids <- nprcgenekeepr::qcBreeders getPotentialSires(ids, ped, minAge = 1L)
Run the code above in your browser using DataLab