powered by
The pedigree provided must have the following columns: sex and age. This needs to be augmented to allow pedigrees structures that are provided by the nprcgenekeepr package.
sex
age
getPyramidPlot( ped = NULL, binWidth = 2L, ageUnit = "years", colorScheme = "default", showCounts = TRUE, ageLabelCex = 1 )
The return value of par("mar") when the function was called.
The pedigree information in data.frame format
numeric bin width for age groups (default 2).
character either "years" (default) or "months".
character color scheme: "default" (blue/pink) or "viridis" (colorblind-friendly).
logical whether to show count values on bars (default TRUE).
numeric expansion factor for age labels (default 1.0).
library(nprcgenekeepr) data(qcPed) getPyramidPlot(qcPed) getPyramidPlot(qcPed, binWidth = 5, colorScheme = "viridis")
Run the code above in your browser using DataLab