| getSiteInfo | R Documentation |
Get site information
getSiteInfo(expectConfigFile = TRUE)
expectConfigFile |
logical parameter when set to |
A list of site specific information used by the application.
Currently this returns the following character strings in a named list.
center – One of "SNPRC" or "ONPRC"
baseUrl – If center is "SNPRC", baseUrl is one of
"https://boomer.txbiomed.local:8080/labkey" or
"https://vger.txbiomed.local:8080/labkey".
To allow testing, if center is "ONPRC" baseUrl is
"https://boomer.txbiomed.local:8080/labkey".
schemaName – If center is "SNPRC", schemaName is
"study". If center is "ONPRC", schemaName is "study"
folderPath – If center is "SNPRC", folderPath is
"/SNPRC". If center is "ONPRC", folderPath is "/ONPRC"
queryName – is "demographics"
requiredCols – the required studbook columns, from
getRequiredCols
possibleCols – the possible studbook columns, from
getPossibleCols
includeColumns – the superset of report-inclusion columns,
from getIncludeColumns
library(nprcgenekeepr)
## default sends warning if configuration file is missing
suppressWarnings(getSiteInfo())
getSiteInfo(expectConfigFile = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.