Learn R Programming

nprcgenekeepr (version 2.0.0)

get_and_or_list: Join a character vector into an and/or list

Description

Join a character vector into an and/or list

Usage

get_and_or_list(c_vector, conjunction = "and")

Value

A character vector of length one containing the a single correctly punctuated character string that list each element in the first arguments vector with commas between if there are more than two elements with the last two elements joined by the selected conjunction.

Arguments

c_vector

Character vector containing the list of words to be put in a list.

conjunction

The conjunction to be used as the connector. This is usually ‘and’ or ‘or’ with ‘and’ being the default.

Examples

Run this code
get_and_or_list(c("Bob", "John")) # "Bob and John"
get_and_or_list(c("Bob", "John"), "or") # "Bob or John"
get_and_or_list(c("Bob", "John", "Sam", "Bill"), "or")
# "Bob, John, Sam, or Bill"

Run the code above in your browser using DataLab