| isFounder | R Documentation |
Part of Pedigree Curation
isFounder(ped)
ped |
a pedigree |
A founder is an animal whose sire and dam are both unknown (NA).
Animals with exactly one known parent (partial parentage) are
not founders.
A logical vector with one element per row of ped that is
TRUE for each animal whose sire and dam are both NA. The
result never contains NA.
getFounders for the founder id values.
library(nprcgenekeepr)
ped <- data.frame(
id = c("A", "B", "C", "D", "E", "F", "G"),
sire = c(NA, NA, "A", "A", NA, "D", "D"),
dam = c(NA, NA, "B", "B", NA, "E", "E"),
stringsAsFactors = FALSE
)
isFounder(ped)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.