Write copy of nprcgenekeepr::examplePedigree into a file
Source:R/makeExamplePedigreeFile.R
makeExamplePedigreeFile.RdUses examplePedigree data structure to create an example data file.
Files of type "csv" and "txt" are silently overwritten if
they already exist. A file of type "excel" is never overwritten;
if the file already exists, an error is signaled.
Examples
library(nprcgenekeepr)
pedigreeFile <- makeExamplePedigreeFile()