Generates an HTML table displaying founder statistics including counts of known founders, male founders, female founders, founder equivalents (FE), and founder genome equivalents (FG).
Arguments
- founderStats
list containing founder statistics with elements:
total- Total number of known foundersnMaleFounders- Number of male foundersnFemaleFounders- Number of female foundersfe- Founder equivalentsfg- Founder genome equivalentsfgSE- (optional) sampling standard error offg; when finite it is shown inline asFG +/- SE
See also
makeGeneticSummaryTable for genetic value summary
calcFE for founder equivalents calculation
calcFG for founder genome equivalents
Examples
stats <- list(
total = 50,
nMaleFounders = 20,
nFemaleFounders = 30,
fe = 25.5,
fg = 22.3
)
html <- makeFounderStatsTable(stats)