Copyright(c) 2017-2025 R. Mark Sharp This file is part of nprcgenekeepr
Details
Generates an HTML table displaying founder statistics including counts of known founders, male founders, female founders, founder equivalents (FE), and founder genome equivalents (FG).
See also
makeGeneticSummaryTable for genetic value summary
calcFE for founder equivalents calculation
calcFG for founder genome equivalents
Examples
if (FALSE) { # \dontrun{
stats <- list(
total = 50,
nMaleFounders = 20,
nFemaleFounders = 30,
fe = 25.5,
fg = 22.3
)
html <- makeFounderStatsTable(stats)
} # }