Learn R Programming

nprcgenekeepr (version 2.0.0)

makeFounderStatsTable: Create Founder Statistics HTML Table

Description

Generates an HTML table displaying founder statistics including counts of known founders, male founders, female founders, founder equivalents (FE), and founder genome equivalents (FG).

Usage

makeFounderStatsTable(founderStats)

Value

Character string containing HTML table markup.

Arguments

founderStats

list containing founder statistics with elements:

  • total - Total number of known founders

  • nMaleFounders - Number of male founders

  • nFemaleFounders - Number of female founders

  • fe - Founder equivalents

  • fg - Founder genome equivalents

  • fgSE - (optional) sampling standard error of fg; when finite it is shown inline as FG +/- SE

See Also

makeGeneticSummaryTable for genetic value summary

calcFE for founder equivalents calculation

calcFG for founder genome equivalents

Examples

Run this code
stats <- list(
  total = 50,
  nMaleFounders = 20,
  nFemaleFounders = 30,
  fe = 25.5,
  fg = 22.3
)
html <- makeFounderStatsTable(stats)

Run the code above in your browser using DataLab