| makeGrpNum | R Documentation |
makeGrpNum has been renamed to makeGroupNum for
consistency with makeGroupMembers. It remains as a deprecated
wrapper that issues a warning and then calls makeGroupNum.
makeGrpNum(numGp)
numGp |
integer value indicating the number of groups that should be formed from the list of IDs. Default is 1. |
Initial grpNum list
makeGroupNum
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.