Learn R Programming

nprcgenekeepr (version 2.0.0)

makeGrpNum: Deprecated alias for makeGroupNum

Description

makeGrpNum has been renamed to makeGroupNum for consistency with makeGroupMembers. It remains as a deprecated wrapper that issues a warning and then calls makeGroupNum.

Usage

makeGrpNum(numGp)

Value

Initial grpNum list

Arguments

numGp

integer value indicating the number of groups that should be formed from the list of IDs. Default is 1.

See Also

makeGroupNum