View source: R/modGvAndBgDesc.R
| modGvAndBgDescServer | R Documentation |
Server logic for genetic value and breeding group description module. This module is primarily informational and does not require reactive logic.
modGvAndBgDescServer(id)
id |
character vector of length 1. Module namespace identifier. |
NULL (no reactive outputs).
modGvAndBgDescUI for the user interface.
Other Shiny modules:
modBreedingGroupsServer(),
modBreedingGroupsUI(),
modGeneticDiversityServer(),
modGeneticDiversityUI(),
modGeneticValueServer(),
modGeneticValueUI(),
modGvAndBgDescUI(),
modInputServer(),
modInputUI(),
modORIPReportingServer(),
modORIPReportingUI(),
modPedigreeServer(),
modPedigreeUI(),
modPotentialParentsServer(),
modPotentialParentsUI(),
modPyramidServer(),
modPyramidUI(),
modSummaryStatsServer(),
modSummaryStatsUI()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.