Skip to contents

Server logic for genetic value and breeding group description module. This module is primarily informational and does not require reactive logic.

Usage

modGvAndBgDescServer(id)

Arguments

id

character vector of length 1. Module namespace identifier.

Value

NULL (no reactive outputs).

See also

modGvAndBgDescUI for the user interface.