Learn R Programming

nprcgenekeepr (version 2.0.0)

modGvAndBgDescServer: Genetic Value and Breeding Group Description Module - Server Function

Description

Server logic for genetic value and breeding group description module. This module is primarily informational and does not require reactive logic.

Usage

modGvAndBgDescServer(id)

Value

NULL (no reactive outputs).

Arguments

id

character vector of length 1. Module namespace identifier.

See Also

modGvAndBgDescUI for the user interface.

Other Shiny modules: modBreedingGroupsServer(), modBreedingGroupsUI(), modGeneticDiversityServer(), modGeneticDiversityUI(), modGeneticValueServer(), modGeneticValueUI(), modGvAndBgDescUI(), modInputServer(), modInputUI(), modORIPReportingServer(), modORIPReportingUI(), modPedigreeServer(), modPedigreeUI(), modPotentialParentsServer(), modPotentialParentsUI(), modPyramidServer(), modPyramidUI(), modSummaryStatsServer(), modSummaryStatsUI()