Server logic for data input module handling file uploads, parsing of pedigree and genotype data files, and quality control validation.
Value
A list with reactive components:
cleanedStudbook- The QC-cleaned studbook datagenotypeData- Genotype data if providedqcSummary- Summary of QC results (error/warning counts)minParentAge- The minimum parent age valueisReady- Logical indicating if data is ready for next step
See also
modInputUI for the user interface.
modPedigreeServer for using the cleaned data.