modInputUI: Data Input and Quality Control Module - UI Function

View source: R/modInput.R

modInputUIR Documentation

Data Input and Quality Control Module - UI Function

Description

Creates user interface for data input including file uploads for pedigree and genotype data with various format options, followed by quality control validation.

Usage

modInputUI(id)

Arguments

id

character vector of length 1. Module namespace identifier.

Value

A div object containing the data input UI.

See Also

modInputServer for server logic.

modPedigreeUI for pedigree browsing after QC.

Other Shiny modules: modBreedingGroupsServer(), modBreedingGroupsUI(), modGeneticDiversityServer(), modGeneticDiversityUI(), modGeneticValueServer(), modGeneticValueUI(), modGvAndBgDescServer(), modGvAndBgDescUI(), modInputServer(), modORIPReportingServer(), modORIPReportingUI(), modPedigreeServer(), modPedigreeUI(), modPotentialParentsServer(), modPotentialParentsUI(), modPyramidServer(), modPyramidUI(), modSummaryStatsServer(), modSummaryStatsUI()


nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.