| modInputUI | R Documentation |
Creates user interface for data input including file uploads for pedigree and genotype data with various format options, followed by quality control validation.
modInputUI(id)
id |
character vector of length 1. Module namespace identifier. |
A div object containing the data input UI.
modInputServer for server logic.
modPedigreeUI for pedigree browsing after QC.
Other Shiny modules:
modBreedingGroupsServer(),
modBreedingGroupsUI(),
modGeneticDiversityServer(),
modGeneticDiversityUI(),
modGeneticValueServer(),
modGeneticValueUI(),
modGvAndBgDescServer(),
modGvAndBgDescUI(),
modInputServer(),
modORIPReportingServer(),
modORIPReportingUI(),
modPedigreeServer(),
modPedigreeUI(),
modPotentialParentsServer(),
modPotentialParentsUI(),
modPyramidServer(),
modPyramidUI(),
modSummaryStatsServer(),
modSummaryStatsUI()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.