Skip to contents

Creates user interface for data input including file uploads for pedigree and genotype data with various format options, followed by quality control validation.

Usage

modInputUI(id)

Arguments

id

character vector of length 1. Module namespace identifier.

Value

A div object containing the data input UI.