Skip to contents

Copyright(c) 2017-2025 R. Mark Sharp This file is part of nprcgenekeepr

Usage

modInputUI(id)

Arguments

id

character vector of length 1. Module namespace identifier.

Value

A div object containing the data input UI.

Details

Creates user interface for data input including file uploads for pedigree and genotype data with various format options, followed by quality control validation.

See also

modInputServer for server logic.

modPedigreeUI for pedigree browsing after QC.