Copyright(c) 2017-2025 R. Mark Sharp This file is part of nprcgenekeepr
Details
Creates user interface for data input including file uploads for pedigree and genotype data with various format options, followed by quality control validation.
See also
modInputServer for server logic.
modPedigreeUI for pedigree browsing after QC.