Learn R Programming

nprcgenekeepr (version 2.0.0)

modInputUI: Data Input and Quality Control Module - UI Function

Description

Creates user interface for data input including file uploads for pedigree and genotype data with various format options, followed by quality control validation.

Usage

modInputUI(id)

Value

A div object containing the data input UI.

Arguments

id

character vector of length 1. Module namespace identifier.

See Also

modInputServer for server logic.

modPedigreeUI for pedigree browsing after QC.

Other Shiny modules: modBreedingGroupsServer(), modBreedingGroupsUI(), modGeneticDiversityServer(), modGeneticDiversityUI(), modGeneticValueServer(), modGeneticValueUI(), modGvAndBgDescServer(), modGvAndBgDescUI(), modInputServer(), modORIPReportingServer(), modORIPReportingUI(), modPedigreeServer(), modPedigreeUI(), modPotentialParentsServer(), modPotentialParentsUI(), modPyramidServer(), modPyramidUI(), modSummaryStatsServer(), modSummaryStatsUI()