Server logic for ORIP reporting module. Generates summary statistics and formatted reports for Office of Research Infrastructure Programs submissions.
See also
modORIPReportingUI for the user interface
getSiteInfo for site configuration
Server logic for ORIP reporting module. Generates summary statistics and formatted reports for Office of Research Infrastructure Programs submissions.
modORIPReportingUI for the user interface
getSiteInfo for site configuration