modORIPReportingUI: ORIP Reporting Module - UI Function

View source: R/modORIPReporting.R

modORIPReportingUIR Documentation

ORIP Reporting Module - UI Function

Description

Creates user interface for ORIP (Office of Research Infrastructure Programs) reporting. This module will contain formatted reports suitable for submission to ORIP as part of primate center grant reporting requirements.

Usage

modORIPReportingUI(id)

Arguments

id

character vector of length 1. Module namespace identifier.

Details

The ORIP Reporting tab provides summary statistics and formatted reports for submission to the Office of Research Infrastructure Programs. This includes:

  • Colony demographics summary

  • Genetic diversity metrics

  • Breeding program statistics

  • Founder representation analysis

Value

A div object containing the ORIP reporting UI.

See Also

modORIPReportingServer for server logic.

Other Shiny modules: modBreedingGroupsServer(), modBreedingGroupsUI(), modGeneticDiversityServer(), modGeneticDiversityUI(), modGeneticValueServer(), modGeneticValueUI(), modGvAndBgDescServer(), modGvAndBgDescUI(), modInputServer(), modInputUI(), modORIPReportingServer(), modPedigreeServer(), modPedigreeUI(), modPotentialParentsServer(), modPotentialParentsUI(), modPyramidServer(), modPyramidUI(), modSummaryStatsServer(), modSummaryStatsUI()


nprcgenekeepr documentation built on July 26, 2026, 5:06 p.m.