Learn R Programming

nprcgenekeepr (version 2.0.0)

modORIPReportingUI: ORIP Reporting Module - UI Function

Description

Creates user interface for ORIP (Office of Research Infrastructure Programs) reporting. This module will contain formatted reports suitable for submission to ORIP as part of primate center grant reporting requirements.

Usage

modORIPReportingUI(id)

Value

A div object containing the ORIP reporting UI.

Arguments

id

character vector of length 1. Module namespace identifier.

Details

The ORIP Reporting tab provides summary statistics and formatted reports for submission to the Office of Research Infrastructure Programs. This includes:

  • Colony demographics summary

  • Genetic diversity metrics

  • Breeding program statistics

  • Founder representation analysis

See Also

modORIPReportingServer for server logic.

Other Shiny modules: modBreedingGroupsServer(), modBreedingGroupsUI(), modGeneticDiversityServer(), modGeneticDiversityUI(), modGeneticValueServer(), modGeneticValueUI(), modGvAndBgDescServer(), modGvAndBgDescUI(), modInputServer(), modInputUI(), modORIPReportingServer(), modPedigreeServer(), modPedigreeUI(), modPotentialParentsServer(), modPotentialParentsUI(), modPyramidServer(), modPyramidUI(), modSummaryStatsServer(), modSummaryStatsUI()