| modPedigreeUI | R Documentation |
Creates user interface for browsing and filtering pedigree data, including focal animal selection, trimming options, and export.
modPedigreeUI(id)
id |
character vector of length 1. Module namespace identifier. |
A div object containing pedigree browser UI.
modPedigreeServer for server logic.
Other Shiny modules:
modBreedingGroupsServer(),
modBreedingGroupsUI(),
modGeneticDiversityServer(),
modGeneticDiversityUI(),
modGeneticValueServer(),
modGeneticValueUI(),
modGvAndBgDescServer(),
modGvAndBgDescUI(),
modInputServer(),
modInputUI(),
modORIPReportingServer(),
modORIPReportingUI(),
modPedigreeServer(),
modPotentialParentsServer(),
modPotentialParentsUI(),
modPyramidServer(),
modPyramidUI(),
modSummaryStatsServer(),
modSummaryStatsUI()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.