Learn R Programming

nprcgenekeepr (version 2.0.0)

modPedigreeUI: Pedigree Browser Module - UI Function

Description

Creates user interface for browsing and filtering pedigree data, including focal animal selection, trimming options, and export.

Usage

modPedigreeUI(id)

Value

A div object containing pedigree browser UI.

Arguments

id

character vector of length 1. Module namespace identifier.

See Also

modPedigreeServer for server logic.

Other Shiny modules: modBreedingGroupsServer(), modBreedingGroupsUI(), modGeneticDiversityServer(), modGeneticDiversityUI(), modGeneticValueServer(), modGeneticValueUI(), modGvAndBgDescServer(), modGvAndBgDescUI(), modInputServer(), modInputUI(), modORIPReportingServer(), modORIPReportingUI(), modPedigreeServer(), modPotentialParentsServer(), modPotentialParentsUI(), modPyramidServer(), modPyramidUI(), modSummaryStatsServer(), modSummaryStatsUI()