Learn R Programming

nprcgenekeepr (version 2.0.0)

modPotentialParentsUI: Potential Parents Module - UI Function

Description

Creates the user interface for identifying potential parents of in-colony animals that have at least one unknown parent. The user sets a maximum gestational period, presses a button to compute candidate sires and dams on the current pedigree, views a sortable results table, and downloads the results as CSV.

Usage

modPotentialParentsUI(id)

Value

A div object containing the Potential Parents UI.

Arguments

id

character vector of length 1. Module namespace identifier.

See Also

modPotentialParentsServer for server logic.

getPotentialParents for the underlying computation.

Other Shiny modules: modBreedingGroupsServer(), modBreedingGroupsUI(), modGeneticDiversityServer(), modGeneticDiversityUI(), modGeneticValueServer(), modGeneticValueUI(), modGvAndBgDescServer(), modGvAndBgDescUI(), modInputServer(), modInputUI(), modORIPReportingServer(), modORIPReportingUI(), modPedigreeServer(), modPedigreeUI(), modPotentialParentsServer(), modPyramidServer(), modPyramidUI(), modSummaryStatsServer(), modSummaryStatsUI()