A data frame with 8 rows and 5 columns (ego_id, sire.id, dam_id, sex, birth_date) representing a full pedigree in which the same male animal is listed as both a sire and a dam.
data(pedSameMaleIsSireAndDam)An object of class data.frame with 8 rows and 5 columns.
It is one of six pedigrees (pedDuplicateIds,
pedFemaleSireMaleDam, pedGood,
pedInvalidDates, pedMissingBirth,
pedSameMaleIsSireAndDam) used to
demonstrate error detection by the qcStudbook function.