Skip to contents

Identifies automatically generated IDs via isGeneratedUnknownId(), the shared detection predicate derived from the configurable auto-ID format (see getAutoIdFormat; default a leading "U"). Routing detection through that single predicate is the "function call" the former inline leading-"U" check was flagged to become.

Usage

removeAutoGenIds(ped)

Arguments

ped

datatable that is the Pedigree. It contains pedigree information. The id, sire, and dame columns are required.

Value

A pedigree with automatically generated IDs removed.

Examples

examplePedigree <- nprcgenekeepr::examplePedigree
length(examplePedigree$id)
#> [1] 3694
ped <- removeAutoGenIds(examplePedigree)
length(ped$id)
#> [1] 2322