Learn R Programming

nprcgenekeepr (version 2.0.0)

removeAutoGenIds: Remove automatically generated IDs from pedigree

Description

Identifies automatically generated IDs via isGeneratedUnknownId(), the shared detection predicate derived from the configurable auto-ID format (see getAutoIdFormat; default a leading "U"). Routing detection through that single predicate is the "function call" the former inline leading-"U" check was flagged to become.

Usage

removeAutoGenIds(ped)

Value

A pedigree with automatically generated IDs removed.

Arguments

ped

datatable that is the Pedigree. It contains pedigree information. The fields id, sire and dam are required.

Examples

Run this code
examplePedigree <- nprcgenekeepr::examplePedigree
length(examplePedigree$id)
ped <- removeAutoGenIds(examplePedigree)
length(ped$id)

Run the code above in your browser using DataLab