View source: R/removePotentialSires.R
| removePotentialSires | R Documentation |
Remove potential sires from a list of IDs
removePotentialSires(ids, minAge, ped)
ids |
character vector of animal IDs |
minAge |
integer value giving the inclusive minimum current age (in years) a male must have to be listed as a potential sire. Default is 1 year. |
ped |
dataframe that is the |
character vector of Ids with any potential sire Ids removed.
library(nprcgenekeepr)
qcBreeders <- nprcgenekeepr::qcBreeders
pedWithGenotype <- nprcgenekeepr::pedWithGenotype
noSires <- removePotentialSires(
ids = qcBreeders, minAge = 2,
ped = pedWithGenotype
)
sires <- getPotentialSires(qcBreeders, ped = pedWithGenotype, minAge = 2)
pedWithGenotype[pedWithGenotype$id %in% noSires, c("sex", "age")]
pedWithGenotype[pedWithGenotype$id %in% sires, c("sex", "age")]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.