powered by
Launches the GeneKeepR Shiny application. It uses a module-based architecture with a Home tab and improved UI components.
runGeneKeepR(port = 6013L, launch.browser = TRUE)
Returns the error condition of the Shiny application when it terminates.
Integer port number for the Shiny server (default 6013)
Logical; whether to launch browser (default TRUE)
The application includes:
Home tab with navigation buttons
Input tab with enhanced QC display
Dynamic error and changed columns tabs
Enhanced Pedigree Browser with focal animal support
Genetic Value Analysis with visualizations
Summary Statistics with popovers
Breeding Groups with group panels
Age-Sex Pyramid with enhanced controls
runModularApp is a soft-deprecated alias for this function.
runModularApp
runModularApp, a soft-deprecated alias for this function.
if (FALSE) { library(nprcgenekeepr) runGeneKeepR() }
Run the code above in your browser using DataLab