Write copy of dataframes to either CSV, TXT, or Excel file
Source:R/saveDataframesAsFiles.R
saveDataframesAsFiles.RdTakes a list of dataframes and creates a file based on the list name of the dataframe and the extension for the file type.
Examples
library(nprcgenekeepr)
dfList <- list(
lacy1989Ped = nprcgenekeepr::lacy1989Ped,
pedGood = nprcgenekeepr::pedGood
)
## Write each data frame to a CSV file under a temporary directory.
files <- saveDataframesAsFiles(dfList,
baseDir = tempdir(), fileType = "csv"
)
basename(files)
#> [1] "lacy1989Ped.csv" "pedGood.csv"