set_seed: Set a reproducible RNG seed across R versions
Description
The change in how set.seed works in R 3.6 prompted the creation of
this R version agnostic replacement to get unit test code to work on multiple
versions of R in a CICD test build.
Usage
set_seed(seed = 1L)
Value
NULL, invisibly.
Arguments
seed
argument to set.seed
Details
It seems RNGkind(sample.kind="Rounding") does not work prior to
version 3.6 so I resorted to using version dependent construction of the
argument list to set.seed() in do.call().