Determine if Changed Columns tab should be displayed
Source:R/shouldShowChangedColsTab.R
shouldShowChangedColsTab.RdChecks the changedCols list to determine if the Changed Columns tab should be inserted into the application navigation. The tab is shown when column names were modified during QC processing.
See also
checkChangedColsLst for the original implementation
Examples
library(nprcgenekeepr)
## No column changes recorded: the tab stays hidden.
shouldShowChangedColsTab(list())
#> [1] FALSE
## A recorded case change: the tab should be shown.
shouldShowChangedColsTab(list(caseChange = c(Id = "id")))
#> [1] TRUE