Determine if Changed Columns tab should be displayed
Source:R/shouldShowChangedColsTab.R
shouldShowChangedColsTab.RdCopyright(c) 2017-2025 R. Mark Sharp This file is part of nprcgenekeepr
Details
Checks the changedCols list to determine if the Changed Columns tab should be inserted into the application navigation. The tab is shown when column names were modified during QC processing.
See also
checkChangedColsLst for the original implementation