Learn R Programming

nprcgenekeepr (version 2.0.0)

shouldShowChangedColsTab: Determine if Changed Columns tab should be displayed

Description

Checks the changedCols list to determine if the Changed Columns tab should be inserted into the application navigation. The tab is shown when column names were modified during QC processing.

Usage

shouldShowChangedColsTab(changedCols)

Value

Logical. TRUE if columns were changed and tab should be shown, FALSE otherwise.

Arguments

changedCols

list containing information about changed column names. Expected fields include: caseChange, spaceRemoved, periodRemoved, underScoreRemoved, egoToId, egoidToId, sireIdToSire, damIdToDam, birthdateToBirth, deathdateToDeath, recordstatusToRecordStatus, fromcenterToFromCenter.

See Also

checkChangedColsLst for the original implementation

Examples

Run this code
library(nprcgenekeepr)
## No column changes recorded: the tab stays hidden.
shouldShowChangedColsTab(list())
## A recorded case change: the tab should be shown.
shouldShowChangedColsTab(list(caseChange = c(Id = "id")))

Run the code above in your browser using DataLab